@@ -14,34 +14,22 @@ plot_timeline_only_noise <- function(result,
 
   p <- ggplot2::ggplot()
 
-  if (utils::packageVersion("ggbeeswarm") == '0.6.0') {
-    p <- p + ggbeeswarm::geom_quasirandom(data = result$hotspots,
-                                          ggplot2::aes(obsTime,
-                                                       membership),
-                                          col = "#d95f02",
-                                          groupOnX = FALSE,
-                                          width = 0.1,
-                                          alpha = max(1/log(noise_num), 0.1),
-                                          size = 1)
-  } else {
-    cli::cli_alert_info("{.fn plot_timeline}: Package {.pkg ggbeeswarm} version is not 0.6.0. {.fn geom_point} will be used insted to draw noise.")
-    p <- p + ggplot2::geom_point(data = result$hotspots,
-                                 ggplot2::aes(obsTime,
-                                              membership),
-                                 col = "#d95f02",
-                                 alpha = max(1/log(noise_num), 0.1),
-                                 size = 1)
-  }
+  p <- p + ggbeeswarm::geom_quasirandom(data = result$hotspots,
+                                        ggplot2::aes(obsTime,
+                                                     membership),
+                                        col = "#d95f02",
+                                        orientation = "y",
+                                        width = 0.1,
+                                        alpha = max(1/log(noise_num), 0.1),
+                                        size = 1)
 
   p <- p +
     ggplot2::geom_density(data = result$hotspots,
                           ggplot2::aes(obsTime, ..scaled../10),
-                          linetype = 2
-    ) +
+                          linetype = 2) +
     ggplot2::geom_density(data = result$hotspots,
                           ggplot2::aes(obsTime, -..scaled../10),
-                          linetype = 2
-    ) +
+                          linetype = 2) +
     ggplot2::theme_bw() +
     ggplot2::theme(axis.text.y = ggplot2::element_blank(),
                    axis.ticks.y = ggplot2::element_blank())
